@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     05/11/2006
-## RCS-ID:      $Id: RichText.pm 2050 2007-05-13 18:38:33Z mbarbon $
+## RCS-ID:      $Id: RichText.pm 2230 2007-09-26 18:36:09Z mbarbon $
 ## Copyright:   (c) 2006-2007 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -42,5 +42,13 @@ package Wx::HtmlListBox;     @ISA = qw(Wx::VListBox);
 package Wx::RichTextStyleListBox; @ISA = qw(Wx::HtmlListBox);
 package Wx::RichTextStyleComboCtrl; @ISA = qw(Wx::ComboCtrl);
 package Wx::RichTextFormattingDialog; @ISA = qw(Wx::PropertySheetDialog);
+package Wx::RichTextXMLHandler; @ISA = qw(Wx::RichTextFileHandler);
+package Wx::RichTextHTMLHandler; @ISA = qw(Wx::RichTextFileHandler);
+package Wx::RichTextObject;
+package Wx::RichTextCompositeObject; @ISA = qw(Wx::RichTextObject);
+package Wx::RichTextBox;     @ISA = qw(Wx::RichTextCompositeObject);
+package Wx::RichTextParagraphLayoutBox; @ISA = qw(Wx::RichTextBox);
+package Wx::RichTextBuffer;  @ISA = qw(Wx::RichTextParagraphLayoutBox);
+package Wx::SymbolPickerDialog; @ISA = qw(Wx::Dialog);
 
 1;
